@@ -2,7 +2,7 @@
 *******************************************************************************
 *
 * File:         bible.c
-* RCS:          $Header: /home/matthew/cvs/bible-kjv-4.10/bible.c,v 2.1 2003/01/08 15:50:53 matthew Exp $
+* RCS:          $Header: /home/matthew/cvs/bible-kjv-4.10/bible.c,v 2.6 2005/01/23 11:14:25 matthew Exp $
 * Description:  Write Bible text to stdout.
 * Author:       Chip Chapin, Hewlett Packard Company
 * Created:      Jan 21 1989
@@ -42,6 +42,25 @@
 *******************************************************************************
 *
 * $Log: bible.c,v $
+* Revision 2.6  2005/01/23 11:14:25  matthew
+* explicit casts
+*
+* Revision 2.5  2005/01/22 18:52:48  matthew
+* No longer write over strings
+*
+* Revision 2.4  2005/01/21 18:55:33  matthew
+* make pretty_print toggling a bit clearer.
+* Remove unused variables.
+* add undeclared functions to brl.h
+* include readline/history.h
+* make main return
+*
+* Revision 2.3  2005/01/21 18:32:25  matthew
+* Remove #defines to bible.h and include that
+*
+* Revision 2.2  2005/01/21 18:24:03  matthew
+* prototype all functions
+*
 * Revision 2.1  2003/01/08 15:50:53  matthew
 * applied debian patch
 *
@@ -144,32 +163,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <readline/readline.h>
+#include <readline/history.h>
 #include "tsl.h"
 #include "brl.h"
 #include "version.h"
-
-#define FALSE	(0)
-#define TRUE	(1)
-
-#define REFSZ     15
-#define VSPECSZ 132
-#define LINESZ 1024
-#define VBUFFSZ 32768
-
-static char rcs_ident[]="@(#)$Header: /home/matthew/cvs/bible-kjv-4.10/bible.c,v 2.1 2003/01/08 15:50:53 matthew Exp $";
-
-
-char *myname;			/* Program Name */
-int  mem_limit;			/* Limit on buffer space used by BRL */
-int  pretty_printing=FALSE;	/* Format the output */
-int  list_always=FALSE;		/* List refs after a search */
-int  line_width=0;		/* Line width to use in formatting */
-int  skip_inc=1;		/* Scrolling direction through text */
-int  select_count=0;		/* Count of verses selected via concordance */
-ref_t selectbuf[SELECTSZ];	/* List of selected verses */
-ref_t inrange_start=0,
-      inrange_end=0;		/* Range limits on concordance selection */
-FILE *outf=NULL;		/* Output file */
+#include "bible.h"
 
 char help_text[]="\n\
  -Bible verse specifications:\n\
@@ -202,7 +200,7 @@ char help_text[]="\n\
 
 
 
-int do_concordance( word, buf )
+int do_concordance(char *word,ref_t *buf )
 /*----------------------------------------------------------------------
 |   NAME:
 |       do_concordance
@@ -216,9 +214,6 @@ int do_concordance( word, buf )
 |       930104 cc Initial creation.
 |
 \*----------------------------------------------------------------------*/
-
-char *word;
-ref_t *buf;
 {
     int cnt;
     char *ref_word;
@@ -254,7 +249,7 @@ ref_t *buf;
 
 
 
-cmd_ANDconcordance( word )
+void cmd_ANDconcordance(char *word)
 /*----------------------------------------------------------------------
 |   NAME:
 |       cmd_ANDconcordance
@@ -267,8 +262,6 @@ cmd_ANDconcordance( word )
 |       921218 cc Initial creation.
 |
 \*----------------------------------------------------------------------*/
-
-char *word;
 {
     int cnt;
     int i, j, k;
@@ -311,7 +304,7 @@ char *word;
 
 
 
-cmd_ORconcordance( word )
+void cmd_ORconcordance(char *word)
 /*----------------------------------------------------------------------
 |   NAME:
 |       cmd_ORconcordance
@@ -324,8 +317,6 @@ cmd_ORconcordance( word )
 |       930104 cc Initial creation.
 |
 \*----------------------------------------------------------------------*/
-
-char *word;
 {
     int cnt;
     int i, j, k;
@@ -375,7 +366,7 @@ char *word;
 
 
 
-cmd_concordance( word )
+void cmd_concordance(char *word)
 /*----------------------------------------------------------------------
 |   NAME:
 |       cmd_concordance
@@ -387,8 +378,6 @@ cmd_concordance( word )
 |       921217 cc Initial creation.
 |
 \*----------------------------------------------------------------------*/
-
-char *word;
 {
     if (*word == '\0') {
 	fprintf( stderr, "To search for a word type '??word'\n" );
@@ -404,7 +393,7 @@ char *word;
 
 
 
-cmd_help()
+void cmd_help(void)
 /*----------------------------------------------------------------------
 |   NAME:
 |       cmd_help
@@ -430,7 +419,7 @@ cmd_help()
 
 
 
-cmd_inrange( range )
+void cmd_inrange(char *range)
 /*----------------------------------------------------------------------
 |   NAME:
 |       cmd_inrange
@@ -448,8 +437,6 @@ cmd_inrange( range )
 |       930104 cc Initial creation.
 |
 \*----------------------------------------------------------------------*/
-
-char *range;
 {
     ref_t start;		/* starting verse */
     int count;			/* number of verses */
@@ -462,8 +449,8 @@ char *range;
 	inrange_start = inrange_end = 0;
 	return;
     }
-
-    if (start = brl_verse_spec( &range, &count )) {
+    /*Assignment used as truth value*/
+    if ((start = brl_verse_spec( &range, &count ))) {
 	inrange_start = start;
 	inrange_end = start + count -1;
 
@@ -499,7 +486,7 @@ char *range;
 
 
 
-cmd_list()
+void cmd_list(void)
 /*----------------------------------------------------------------------
 |   NAME:
 |       cmd_list
@@ -555,7 +542,7 @@ cmd_list()
 
 
 
-cmd_pretty_print(verbose)
+void cmd_pretty_print(int verbose)
 /*----------------------------------------------------------------------
 |   NAME:
 |       cmd_pretty_print
@@ -568,11 +555,12 @@ cmd_pretty_print(verbose)
 |
 \*----------------------------------------------------------------------*/
 
-int verbose;
 {
     char *s;
+    /*invert the pretty_printing setting*/
+    pretty_printing=pretty_printing ? FALSE : TRUE;
     
-    if (pretty_printing = pretty_printing ? FALSE : TRUE) {
+    if (pretty_printing) {
 	if (line_width == 0) {
 	    /*
 	      This forces pretty_printing to be done with a
@@ -600,7 +588,7 @@ int verbose;
 
 
 
-cmd_view()
+void cmd_view(void)
 /*----------------------------------------------------------------------
 |   NAME:
 |       cmd_view
@@ -634,7 +622,7 @@ cmd_view()
 
 
 
-cmd_write( fname )
+void cmd_write(char *fname)
 /*----------------------------------------------------------------------
 |   NAME:
 |       cmd_write
@@ -653,8 +641,6 @@ cmd_write( fname )
 |       930105 cc Initial creation.
 |
 \*----------------------------------------------------------------------*/
-
-char *fname;
 {
     if (outf != NULL) {
 	fclose( outf );
@@ -672,7 +658,7 @@ char *fname;
 
 
 
-do_command( cmd )
+void do_command(char *cmd)
 /*----------------------------------------------------------------------
 |   NAME:
 |       do_command
@@ -685,8 +671,6 @@ do_command( cmd )
 |       921217 cc Initial creation
 |
 \*----------------------------------------------------------------------*/
-
-char *cmd;
 {
     int n;
     char w[VSPECSZ];
@@ -694,7 +678,7 @@ char *cmd;
 
     /* Convert to lower case */
     for (p=cmd; *p; p++) {
-	if (isupper(*p)) *p = tolower(*p);
+	if (isupper((int)*p)) *p =tolower((int)*p);
     }
     n=sscanf(cmd, "?%s", w);
 
@@ -772,7 +756,7 @@ char *cmd;
 
 
 
-user_input( cmd )
+void user_input(char  *cmd)
 /*----------------------------------------------------------------------
 |   NAME:
 |       user_input
@@ -788,11 +772,8 @@ user_input( cmd )
 |       921217 cc Initial creation.
 |
 \*----------------------------------------------------------------------*/
-
-char *cmd;
 {
     char vs[REFSZ];
-    int  b, c, v;	/* Junk variables */
     
     get_nonblank(cmd);
 	
@@ -819,7 +800,7 @@ char *cmd;
 
 
 
-char *getprompt()
+char *getprompt(void)
 /*----------------------------------------------------------------------
 |   NAME:
 |       getprompt
@@ -845,7 +826,7 @@ char *getprompt()
 
 
 
-usage()
+void usage(void)
 /*----------------------------------------------------------------------
 |   NAME:
 |       usage
@@ -876,7 +857,7 @@ usage()
 
 
 
-main(argc, argv)
+int main(int argc,char **argv)
 /*----------------------------------------------------------------------
 |   NAME:
 |       main
@@ -895,13 +876,11 @@ main(argc, argv)
 |       890912 cc Added -f, -l options.
 |
 \*----------------------------------------------------------------------*/
-
-int argc;
-char **argv;
 {
   char *line;
   char *dfname, *dfpath, *s;
   char ch;
+  char def_verse[]="Gen1:1";
 
   mem_limit = 1024;		/* Default 1024K of buffer space */
   dfname = dfpath = NULL;	/* Use library's default values */
@@ -931,13 +910,13 @@ char **argv;
 	      cmd_pretty_print(FALSE);
 	      break;
 	    case 'l':
-	      if (isdigit(*(*argv+1))) {
+	      if (isdigit((int)*(*argv+1))) {
 		  line_width = atoi(++(*argv));
 		  if (line_width > LINESZ) line_width = LINESZ -1;
 		  goto nextarg;
 	      } else if (--argc
-			 && isdigit(*(argv[1]))
-			 && ((ch= *(argv[1]+1)) == '\0' || isdigit(ch))) {
+			 && isdigit((int)*(argv[1]))
+			 && ((ch= *(argv[1]+1)) == '\0' || isdigit((int)ch))) {
 		  line_width = atoi(*++argv);
 		  if (line_width > LINESZ) line_width = LINESZ -1;
 		  goto nextarg;
@@ -953,7 +932,7 @@ char **argv;
 	      }
 	      break;
 	    case 'm':
-	      if (!ARGVAL() || !isdigit(**argv)) {
+	      if (!ARGVAL() || !isdigit((int)**argv)) {
 		  fprintf(stderr, "%s: -m Missing memory-limit\n", myname);
 		  usage();
 	      }
@@ -987,7 +966,7 @@ char **argv;
       printf( "%s: %s\n", myname, release_version );
       printf( "Hit '?' for help.\n" );
       rl_bind_key('\t', rl_insert);
-      brl_printverse( "Gen1:1", pretty_printing, line_width, outf );
+      brl_printverse( def_verse, pretty_printing, line_width, outf );
       while((line = readline(getprompt())) != NULL) {
 	  user_input( line );
 	  if (*line != '\0') add_history(line);
@@ -997,4 +976,5 @@ char **argv;
   }
   
   brl_close();
+  return(0);
 } /* main */
